**In the near future,** this will be the file hierarchy here:

```
/open_interpreter
  /cli
    cli.py
    chat.py
    /utils
  /core
    core.py
    respond.py
    /utils
    /code_interpreter
      /languages
        python.py
        shell.py
        ...
      language_map.py
      ...
    ...
```
